@@ -39,13 +39,13 @@ def parse_options():
         help="put your har folder path for production"
     )
 
-    parser.add_option(
-       '--skip-response',
-        dest='skip_response',
-        action='store_true',
-        default=False,
-        help="skip set response"
-    )
+    # parser.add_option(
+    #    '--skip-response',
+    #     dest='skip_response',
+    #     action='store_true',
+    #     default=False,
+    #     help="skip set response"
+    # )
 
     # Finalize
     # Return three-tuple of parser + the output from parse_args (opt obj, args)
