@@ -1,5 +1,5 @@
 from optparse import OptionParser
-import os, sys
+import sys
 from . import tkp_struct, args_parser, multihar
 from collections import OrderedDict
 
